from distutils.core import setup
setup(
     name = 'nesterMatano',
     version = '1.3.0',
     py_modules = ['nesterMatano'],
     author = 'Matano',
     author_email = 'mwakimamatano@gmail.com',
     description = 'A simple printer of nested lists',
)
